@@ -40,9 +40,9 @@
   are_enough_colors_available <- palette_length > min_length
 
   if (!are_enough_colors_available) {
-    rlang::inform(c(
-      "Number of labels is greater than default palette color count.",
-      "Select another color `palette` (and/or `package`)."
+    rlang::warn(c(
+      x = "Number of labels is greater than default palette color count.",
+      i = "Select another color `palette` (and/or `package`)."
     ))
   }
 
